clear
capture log close
set more off



*** Global
global root "C:\Users\walke\Dropbox\Shipbuilding project\JEEA_replication_files"

global temp "$root\temp"
global results "$root\results"


**** Load main data 
use "$root\data\analysis_data_location_decade_long", clear

** Focus on US only
count
keep if country=="US" | country=="CANADA"
keep if region=="atlantic" | region=="great lakes"
drop if decade<1850
count

** Merge in area TT
sort country state county
merge m:1 country state county using "$root\translation_tables\county_area_tt"
tab _merge
drop _merge
replace area="ottawa" if location=="Temiscaming"
encode area, gen(area_code)

*** Treat DC as the same as Maryland
replace state="MD" if state=="DC"

**** Merge in iron and wood price controls
sort state
merge m:1 state using "$root\data\controls_lumber_prices"
tab _merge
drop if _merge==2
drop _merge
rename lumber_price_weighted lumber_pr_w
rename lumber_price_unweighted lumber_pr_uw

sort state
merge m:1 state using "$root\data\controls_iron_prices"
tab _merge
drop if _merge==2
drop _merge

**** Merge in local industrial composition
replace county=upper(county)
sort country state county
merge m:1 country state county using "$root\data\controls_county_metalworking"
tab _merge
drop if _merge==2
drop _merge

gen ln_county_pop=ln(county_pop)
gen county_metal_shr=metal_emp/county_pop
gen county_lumber_shr=lumber_emp/county_pop


** 
replace state="DC" if state=="MD" & location=="Washington"

reshape wide tons_ max_tons_ , i(country location state region ship_material latitude longitude dist_naval_shipyard) j(decade)

** Merge in nearby tonnage data
sort location country state
merge 1:1 location country state ship_material using "$root\data\nearby_tons_US_CA_LONG"
tab _merge
drop if _merge==2
drop _merge


** generate unique location identifiers
gen lc=location+"_"+country+"_"+state
encode lc, gen(loc_code)

** fillin locations
count
fillin loc_code ship_material
count

order loc_code ship_material
gsort loc_code -ship_material

foreach i in country location state region {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==""
}

foreach i in latitude longitude dist_naval_shipyard iron_price lumber_pr_w lumber_pr_uw county_metal_shr county_lumber_shr ln_county_pop{
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==.
}

gsort loc_code ship_material

foreach i in country location state region {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==""
}

foreach i in latitude longitude dist_naval_shipyard iron_price lumber_pr_w lumber_pr_uw county_metal_shr county_lumber_shr ln_county_pop{
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==.
}



forval i = 1850(10)1900 {
rename tons_`i' tons_`i's
replace tons_`i's=0 if tons_`i's==.
}

bysort loc_code: egen tons_loc_1870s_50km=sum(tons_1870s_50km)
bysort loc_code: egen tons_loc_1870s_100km=sum(tons_1870s_100km)
gen ln_tons_loc_1870s_100km=ln(tons_loc_1870s_100km)
gen ln_tons_1870s_100km=ln(tons_1870s_100km)

bysort loc_code: egen tons_loc_1850s_50km=sum(tons_1850s_50km)
bysort loc_code: egen tons_loc_1850s_100km=sum(tons_1850s_100km)
gen ln_tons_loc_1850s_100km=ln(tons_loc_1850s_100km)
gen ln_tons_1850s_100km=ln(tons_1850s_100km)

gen us_flag=0
replace us_flag=1 if country=="US" & region=="atlantic"
gen great_lakes=0
replace great_lakes=1 if region=="great lakes"
gen great_lakes_US=0
replace great_lakes_US=1 if country=="US" & region=="great lakes"
gen great_lakes_CA=0
replace great_lakes_CA=1 if country=="CANADA" & region=="great lakes"



forval i = 1850(10)1900 {
gen ln_tons_`i's=ln(tons_`i's)
gen ln_max_tons_`i's=ln(max_tons_`i')

gen act_`i'=0
replace act_`i'=1 if tons_`i's>0
bysort loc_code: egen act_loc_`i'=max(act_`i')

bysort loc_code: egen tons_loc_`i'=sum(tons_`i's)
gen ln_tons_loc_`i'=ln(tons_loc_`i')

gen share_`i'=tons_`i's/tons_loc_`i'

}



gen iron=0
replace iron=1 if ship_material=="iron"
gen us_flag_iron=us_flag*iron
gen great_lakes_iron=great_lakes*iron
gen great_lakes_US_iron=great_lakes_US*iron
gen great_lakes_CA_iron=great_lakes_CA*iron

gen wood=0 
replace wood=1 if ship_material=="wood"

gen nearby_navy_25=0
replace nearby_navy_25=1 if dist_naval_shipyard<25
gen nearby_navy_iron_25=nearby_navy_25*iron
gen nearby_navy_wood_25=nearby_navy_25*wood

gen nearby_navy_50=0
replace nearby_navy_50=1 if dist_naval_shipyard<50
gen nearby_navy_iron_50=nearby_navy_50*iron
gen nearby_navy_wood_50=nearby_navy_50*wood

gen nearby_navy_100=0
replace nearby_navy_100=1 if dist_naval_shipyard<100
gen nearby_navy_iron_100=nearby_navy_100*iron
gen nearby_navy_wood_100=nearby_navy_100*wood


** change tons to 1000s
replace tons_1870s=tons_1870s/10000
replace tons_loc_1870=tons_loc_1870/10000

***** log prices
gen ln_iron_price=ln(iron_price)
gen ln_lumber_price_weighted=ln(lumber_pr_w)
gen iron_price_inter=ln_iron_price*iron
gen wood_price_inter=ln_lumber_price_weighted*iron


** label variables
label variable iron "Metal indicator"
label variable us_flag "U.S. indicator"
label variable great_lakes "Great Lakes indicator"
label variable us_flag_iron "U.S. x Metal indicator"
label variable great_lakes_iron "Great Lakes x Metal indicator"

label variable act_1870 "Active in the same sector-location in 1871-80"
label variable act_loc_1870 "Active shipbuilding location in 1871-80"
label variable tons_1870s "Tons in the same sector-location in 1871-80"
label variable tons_loc_1870 "Total tons in the location in 1871-80"

label variable ln_iron_price "Log iron price"
label variable ln_lumber_price_weighted "Log lumber price"
label variable iron_price_inter "Log iron price x Metal"
label variable wood_price_inter "Log lumber price x Metal"

label variable nearby_navy_25 "Navy yard within 25km"
label variable nearby_navy_50 "Navy yard within 50km"
label variable nearby_navy_100 "Navy yard within 100km"


***** Proximity to Navy Shipyard results -- Robustness
gen act_loc_wood_1870=0
replace act_loc_wood_1870=1 if act_1870==1 & ship_material=="wood"
bysort location state country: egen active_wood_1870=sum(act_loc_wood_1870)
drop act_loc_wood_1870

gen navy_contract=0
replace navy_contract=1 if location=="Bath" & country=="US"
replace navy_contract=1 if location=="Baltimore" & country=="US"
replace navy_contract=1 if location=="Philadelphia" & country=="US"
replace navy_contract=1 if location=="New York" & country=="US"
replace navy_contract=1 if location=="Camden,NJ" & country=="US"
replace navy_contract=1 if location=="New London" & country=="US"
replace navy_contract=1 if location=="Quincy" & country=="US"
replace navy_contract=1 if location=="Wilmington, Del" & country=="US"
replace navy_contract=1 if location=="Bristol" & country=="US"
replace navy_contract=1 if location=="Bridgeport" & country=="US"
replace navy_contract=1 if location=="Boston" & country=="US"
replace navy_contract=1 if location=="Seattle" & country=="US"
replace navy_contract=1 if location=="Newport News" & country=="US"
replace navy_contract=1 if location=="Richmond, VA" & country=="US"
replace navy_contract=1 if location=="San Francisco" & country=="US"
replace navy_contract=1 if location=="Chester, Pa" & country=="US"

gen navy_contract_iron=navy_contract*iron


reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & active_wood_1870==1, cluster(loc_code)
est store NN0
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron navy_contract navy_contract_iron if us_flag==1 & great_lakes==0 & act_1900==1, cluster(loc_code)
est store NN1
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="NY" & state!="NJ" & state!="CT", cluster(loc_code)
est store NN2
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="PA" & state!="DE", cluster(loc_code)
est store NN3
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="ME" & state!="MA", cluster(loc_code)
est store NN4
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="VA", cluster(loc_code)
est store NN5
test nearby_navy_iron_50=nearby_navy_50

outreg2 [NN0 NN1 NN2 NN3 NN4 NN5]  using "$root\appendix_tables_figures\Table_A16\Table_A16", tex drop(_I*) replace label



***** Proximity to Navy Shipyard results -- Robustness -- clustered by area

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & active_wood_1870==1, cluster(area_code)
est store NN0
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron navy_contract navy_contract_iron if us_flag==1 & great_lakes==0 & act_1900==1, cluster(area_code)
est store NN1
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="NY" & state!="NJ" & state!="CT", cluster(area_code)
est store NN2
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="PA" & state!="DE", cluster(area_code)
est store NN3
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="ME" & state!="MA", cluster(area_code)
est store NN4
test nearby_navy_iron_50=nearby_navy_50

reg ln_tons_1900s nearby_navy_iron_50 nearby_navy_50 iron if us_flag==1 & great_lakes==0 & act_1900==1 & state!="VA", cluster(area_code)
est store NN5
test nearby_navy_iron_50=nearby_navy_50

outreg2 [NN0 NN1 NN2 NN3 NN4 NN5]  using "$root\appendix_tables_figures\Table_A16\Table_A16_clustered_by_area", tex drop(_I*) replace label


****
