clear
capture log close
set more off


*** Laptop global
global root "C:\Users\walke\Dropbox\Shipbuilding project\JEEA_replication_files"


global temp "$root\temp"
global results "$root\results"

****
use "$root\data\analysis_data_location_decade_long", clear

drop if decade==1840

** Focus on US & Canada East
count
keep if country=="US"  | country=="CANADA"
keep if region=="atlantic" | region=="great lakes"
count


** generate unique location identifiers
gen lc=location+"_"+country+"_"+state
encode lc, gen(loc_code)
drop lc 

** fillin locations
count
fillin loc_code ship_material decade
count

order loc_code ship_material decade
gsort loc_code -ship_material decade

foreach i in country location state region {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==""
}

foreach i in latitude longitude dist_naval_shipyard {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==.
}

gsort loc_code ship_material decade

foreach i in country location state region {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==""
}

foreach i in latitude longitude dist_naval_shipyard {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==.
}

rename tons_ tons
replace tons=0 if tons==.
bysort loc_code decade: egen tons_loc=sum(tons)

gen ln_tons=ln(tons)
gen ln_loc_tons=ln(tons_loc)
gen active=0
replace active=1 if tons>0
gen active_loc=0
replace active_loc=1 if tons_loc>0

gen us_flag=0
replace us_flag=1 if country=="US" & region=="atlantic"
gen great_lakes=0
replace great_lakes=1 if region=="great lakes"


gen iron=0
replace iron=1 if ship_material=="iron"
gen us_flag_iron=us_flag*iron
gen great_lakes_iron=great_lakes*iron
gen dist_navy_iron=dist_naval_shipyard*iron

gen wood=0 
replace wood=1 if ship_material=="wood"
gen us_flag_wood=us_flag*wood
gen great_lakes_wood=great_lakes*wood
gen dist_navy_wood=dist_naval_shipyard*wood

gen us_lakes_iron=us_flag*great_lakes*iron
gen us_lakes=us_flag*great_lakes


** change tons to 1000s
replace tons=tons/10000


** label variables
label variable iron "Metal indicator"
label variable us_flag "U.S. indicator"
label variable great_lakes "Great Lakes indicator"
label variable us_flag_iron "U.S. x Metal indicator"
label variable great_lakes_iron "Great Lakes x Metal indicator"
label variable active "Active in the same sector-location in 1871-80"
label variable active_loc "Active shipbuilding location in 1871-80"
label variable tons "Tons in the same sector-location in 1871-80"
label variable tons_loc "Total tons in the location in 1871-80"


****
drop if country==""
drop if ship_material==""
gen lc=location+"_"+country+"_"+state+"_"+ship_material
gen lc2=location+"_"+country+"_"+state
encode lc, gen(Xcode)
xtset Xcode decade

gen GLI=great_lakes_iron
gen USI=us_flag_iron

gen GLW=great_lakes_wood
gen USW=us_flag_wood

xi i.USW*i.decade i.GLW*i.decade i.iron*i.decade i.GLI*i.decade i.USI*i.decade, noomit

drop _IUSW_0 _IUSW_1 _IUSI_0 _IUSI_1 _IGLW_0 _IGLW_1 _IGLI_0 _IGLI_1 _Iiron_0 _Iiron_1 _Idecade_1850 _IUSWXdec_0* _IUSIXdec_0* _IGLWXdec_0* _IGLIXdec_0* _IiroXdec_0* 


**** REGRESSIONS
****************************

xtreg tons _I*, vce(cluster lc2)
est store FET
outreg2 [FET] using "$root\results\Figure_06\Figure_06", excel replace label noaster

****
